@@ -19,11 +19,11 @@ install the SDK as a development-only dependency.
 from typing import Any, Callable, Dict, List, Type
 
 from touca._client import Client
-from touca._runner import Workflow, workflow, run
+from touca._rules import ComparisonRule, decimal_rule
+from touca._runner import Workflow, run, workflow
+from touca._transport import __version__
 from touca._utils import scoped_timer
 
-__version__ = "1.8.0"
-
 
 def clientmethod(f):
     import inspect
@@ -47,11 +47,6 @@ def configuration_error() -> str:
     return Client.instance().configuration_error()
 
 
-@clientmethod
-def get_testcases() -> List[str]:
-    return Client.instance().get_testcases()
-
-
 @clientmethod
 def declare_testcase(name: str):
     Client.instance().declare_testcase(name)
@@ -63,8 +58,8 @@ def forget_testcase(name: str):
 
 
 @clientmethod
-def check(key: str, value: Any):
-    Client.instance().check(key, value)
+def check(key: str, value: Any, *, rule: ComparisonRule = None):
+    Client.instance().check(key, value, rule=rule)
 
 
 @clientmethod
