@@ -1,4 +1,4 @@
-# Copyright 2022 Touca, Inc. Subject to Apache-2.0 License.
+# Copyright 2023 Touca, Inc. Subject to Apache-2.0 License.
 
 from argparse import Action, ArgumentParser
 from configparser import ConfigParser
@@ -12,6 +12,7 @@ class ToucaError(RuntimeError):
     codes = {
         "auth_invalid_key": "Authentication failed: API Key Invalid.",
         "auth_invalid_response": "Authentication failed: Invalid Response.",
+        "auth_server_down": "Touca server appears to be down",
         "config_file_invalid": 'Configuration file has an unexpected format: "{}"',
         "config_file_missing": 'Configuration file does not exist: "{}"',
         "config_option_invalid": 'Configuration option "{}" has unexpected type.',
@@ -22,6 +23,7 @@ class ToucaError(RuntimeError):
         "testcase_forget": 'Test case "{}" was never declared.',
         "transport_http": "HTTP request failed: {}",
         "transport_options": "Failed to fetch options from the remote server.",
+        "remote_options_sealed": "The specified version is already submitted.",
         "type_mismatch": 'Specified key "{}" has a different type.',
         "workflows_missing": "No workflow is registered.",
     }
@@ -229,8 +231,8 @@ def apply_cli_arguments(options: dict):
     from sys import argv
 
     parser = ArgumentParser(
-        description="Touca Regression Test",
-        epilog="Visit https://touca.io/docs for more information",
+        description="Touca Test Runner",
+        epilog="See https://touca.io/docs for more information.",
     )
     prepare_parser(parser)
     parsed = vars(parser.parse_known_args(options.get("arguments", argv[1:]))[0])
@@ -284,6 +286,15 @@ def apply_core_options(options: dict):
         options["api_url"] = "https://api.touca.io"
 
 
+def authenticate(options: dict, transport: Transport):
+    if (
+        options.get("offline") == False
+        and "api_key" in options
+        and "api_url" in options
+    ):
+        transport.configure(options)
+
+
 def apply_runner_options(options: dict):
     options.setdefault("output_directory", find_home_path().joinpath("results"))
     options.setdefault("workflows", [])
@@ -309,16 +320,22 @@ def apply_runner_options(options: dict):
     options.pop("testcases", None)
 
 
-def fetch_remote_options(input, transport):
+def fetch_remote_options(input, transport: Transport):
     from json import loads
 
     response = transport.request(method="POST", path="/client/options", body=input)
+    if response.status == 401:
+        raise ToucaError("auth_invalid_key")
+    if response.status == 409:
+        raise ToucaError("remote_options_sealed")
     if response.status != 200:
         raise ToucaError("transport_options")
     return loads(response.data.decode("utf-8"))
 
 
 def apply_remote_options(options: dict, transport: Transport):
+    if options.get("offline") or "api_key" not in options or "api_url" not in options:
+        return
     workflows: List[dict] = options.get("workflows")
     if not workflows:
         return
@@ -380,7 +397,6 @@ def validate_runner_options(options: dict):
         [
             "api_key",
             "api_url",
-            "config_file",
             "suite",
             "team",
             "version",
@@ -400,16 +416,10 @@ def validate_runner_options(options: dict):
 
 
 def update_core_options(options: dict, transport: Transport):
-    apply_config_file(options)
     apply_environment_variables(options)
     apply_api_url(options)
     apply_core_options(options)
-    if (
-        options.get("offline") == False
-        and "api_key" in options
-        and "api_url" in options
-    ):
-        transport.authenticate(options.get("api_url"), options.get("api_key"))
+    authenticate(options, transport)
     return validate_core_options(options)
 
 
@@ -420,17 +430,7 @@ def update_runner_options(options: dict, transport: Transport):
     apply_environment_variables(options)
     apply_api_url(options)
     apply_core_options(options)
-    if (
-        options.get("offline") == False
-        and "api_key" in options
-        and "api_url" in options
-    ):
-        transport.authenticate(options.get("api_url"), options.get("api_key"))
+    authenticate(options, transport)
     apply_runner_options(options)
-    if (
-        options.get("offline") == False
-        and "api_key" in options
-        and "api_url" in options
-    ):
-        apply_remote_options(options, transport)
+    apply_remote_options(options, transport)
     validate_runner_options(options)
