@@ -1,9 +1,10 @@
-# Copyright 2022 Touca, Inc. Subject to Apache-2.0 License.
+# Copyright 2023 Touca, Inc. Subject to Apache-2.0 License.
 
 import logging
 import sys
 from argparse import ArgumentParser
 from pathlib import Path
+from typing import Dict, List, Union
 
 import touca
 from touca._runner import run_workflows
@@ -15,19 +16,41 @@ logger = logging.getLogger("touca.cli.check")
 def _get_file_content(file: Path):
     try:
         return file.read_text()
-    except:
-        from hashlib import sha256
-
-        return sha256(file.read_bytes()).hexdigest()
+    except ValueError:
+        return file.read_bytes()
 
 
-def _slugify(file: Path):
-    return (
-        str(file.absolute().relative_to(Path.cwd()))
-        .replace(".", "_")
-        .replace("/", "_")
-        .replace("-", "_")
-    )
+def _slugify(name: str):
+    return name.replace(".", "_").replace("/", "_").replace("-", "_")
+
+
+def _parse(files: List[Path], testcase: Union[str, None]):
+    from os.path import commonpath
+    from collections import defaultdict
+
+    output: Dict[str, Dict[str, Path]] = {}
+    excluded = [".DS_Store"]
+    files = [
+        file.resolve() for file in files if file.is_file() and file.name not in excluded
+    ]
+    common = commonpath(files)
+    tree = defaultdict(list)
+    for file in files:
+        item = (
+            testcase
+            if testcase
+            else file.name
+            if len(files) == 1 or file.parent == Path(common)
+            else str(file.parent.relative_to(common))
+        )
+        tree[_slugify(item)].append(file)
+    for k, v in tree.items():
+        common = commonpath(v)
+        output[k] = {
+            _slugify("output" if len(v) == 1 else str(f.relative_to(common))): f
+            for f in v
+        }
+    return output
 
 
 class CheckCommand(CliCommand):
@@ -70,41 +93,21 @@ class CheckCommand(CliCommand):
             testcases=[testcase if testcase else "stdout"],
         )
 
-    def _submit_file(self, file: Path):
-        content = file.read_text()
-
-        def _submit(_):
-            touca.check("output", content)
-
-        testcase = self.options.get("testcase")
-        self._run(
-            callback=_submit,
-            testcases=[testcase if testcase else _slugify(file)],
-        )
-
-    def _submit_directory(self, directory: Path):
-        files = {_slugify(file): file for file in directory.glob("*") if file.is_file()}
+    def _submit_testcases_map(self, files):
+        testcases = _parse(files, self.options.get("testcase"))
 
         def _submit(testcase: str):
-            if not self.options.get("testcase"):
-                content = _get_file_content(files.get(testcase))
-                touca.check("output", content)
-                return
-            for slug, file in files.items():
-                touca.check(slug, _get_file_content(file))
+            for key, file in testcases[testcase].items():
+                touca.check(key, _get_file_content(file))
 
-        testcase = self.options.get("testcase")
-        self._run(
-            callback=_submit,
-            testcases=[testcase] if testcase else list(files.keys()),
-        )
+        self._run(callback=_submit, testcases=list(testcases.keys()))
 
     def run(self):
         if not sys.stdin.isatty():
             return self._submit_stdin()
         src = Path(self.options.get("src"))
         if src.is_file():
-            return self._submit_file(src)
+            return self._submit_testcases_map([src])
         if src.is_dir():
-            return self._submit_directory(src)
+            return self._submit_testcases_map(sorted(src.rglob("*")))
         logger.error("specified path is neither a directory nor a file")
